@@ -47,6 +47,7 @@ import d1_common.url
 # App.
 import workspace_exception
 
+# Replaced with the python.requests library.
 
 ## SolrConnection is a thin layer on top of HTTPSConnection that automatically
 ## retries queries and connection attempts.
@@ -115,7 +116,8 @@ import workspace_exception
 ##===============================================================================
 
 class SolrClient(object):
-  def __init__(self, base_url, solr_selector='/v1/query/solr/', max_retries=3, timeout=30, max_objects_for_query=50):
+  def __init__(self, base_url, solr_selector='/v1/query/solr/', max_retries=3,
+               timeout=30, max_objects_for_query=50):
     self._solr_endpoint = base_url + solr_selector
     self._session = requests.Session()
     self._session.mount('http://', requests.adapters.HTTPAdapter(max_retries=max_retries))
@@ -137,7 +139,8 @@ class SolrClient(object):
     if filter_queries is not None:
       query_params.extend(self._make_query_param_tuples('fl', filter_queries))
 
-    r = requests.get(self._solr_endpoint, timeout=self._timeout, params=query_params)
+    r = requests.get(self._solr_endpoint, timeout=self._timeout, params=query_params,
+                     verify=False)
     return r.json()
 
 
